#!/bin/bash

set -e

BUILD_NAME="opMLSMPPRouter_1a9d472"
APP_NAME="opMLSMPPRouter"
INSTALL_DIR="/usr/local/bin"
SERVICE_NAME="mlsmpprouter"
SERVICE_FILE="/etc/systemd/system/${SERVICE_NAME}.service"

echo "Installing ${BUILD_NAME}..."

if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root. Use sudo."
   exit 1
fi

if [ ! -f "${BUILD_NAME}" ]; then
  echo "Error: ${BUILD_NAME} binary not found in current directory."
  exit 1
fi

install -m 755 "${BUILD_NAME}" "${INSTALL_DIR}/${BUILD_NAME}"

echo "Installing smpproutercli script..."
install -m 755 smpproutercli.sh "${INSTALL_DIR}/smpproutercli.sh"
ln -sf "${INSTALL_DIR}/smpproutercli.sh" "${INSTALL_DIR}/smpproutercli"

echo "Creating symlink ${APP_NAME} -> ${BUILD_NAME}..."
ln -sf "${INSTALL_DIR}/${BUILD_NAME}" "${INSTALL_DIR}/${APP_NAME}"

# Ensure INSTALL_DIR is in user's PATH immediately and persistently
if ! echo "/usr/local/bin:/usr/bin:/bin:/usr/local/games:/usr/games" | grep -q ""; then
  echo "Adding  to PATH..."

  # Add for current session
  export PATH="/usr/local/bin:/usr/bin:/bin:/usr/local/games:/usr/games:"

  # Attempt to persist for the actual user
  SHELL_RC=""
  if [ -n "" ]; then
    USER_HOME=/home/admin
    if [ -f "/.bashrc" ]; then
      SHELL_RC="/.bashrc"
    elif [ -f "/.profile" ]; then
      SHELL_RC="/.profile"
    fi

    if [ -n "" ]; then
      echo "export PATH=$PATH:" >> ""
      echo "Added '' to PATH in "
    else
      echo "Warning: Could not find a shell startup file to persist PATH update."
    fi
  fi
fi

echo "Creating systemd service..."

cat > "${SERVICE_FILE}" <<SERVICE
[Unit]
Description=Melrose Labs SMPP Router
After=network.target

[Service]
Type=simple
WorkingDirectory=/home/admin/smpprouter
ExecStart=${INSTALL_DIR}/${APP_NAME}
Restart=on-failure
User=root
AmbientCapabilities=CAP_NET_BIND_SERVICE

[Install]
WantedBy=multi-user.target
SERVICE

echo "Creating base configuration..."
${INSTALL_DIR}/${APP_NAME}

echo "Enabling and starting service..."
systemctl daemon-reexec
systemctl daemon-reload
systemctl enable "${SERVICE_NAME}"
systemctl start "${SERVICE_NAME}"

echo "Installation complete. Service '${SERVICE_NAME}' is running."
